Pkcs11Token

Struct Pkcs11Token 

pub struct Pkcs11Token {
    pub id: i64,
    pub module_path: PathBuf,
    pub label: String,
    pub manufacturer_id: Option<String>,
    pub model: Option<String>,
    pub serial_number: String,
    pub concurrent_requests: i64,
}

Fields

id: i64

The table’s primary key.

module_path: PathBuf

Absolute path to the PKCS#11 module to use when accessing the token.

label: String

The token’s label, useful for identification purposes

manufacturer_id: Option<String>

The token’s manufacturer ID, useful for identification purposes

model: Option<String>

The token’s model, useful for identification purposes

serial_number: String

The token’s serial number; used to find the token among all available PKCS#11 slots managed by the given module.

concurrent_requests: i64

The number of concurrent signing requests; this translates to the number of open sessions and signing operations. Some tokens have limits. The default, 0, means no limit.

Implementations

Source

impl Pkcs11Token

pub async fn create( conn: &mut SqliteConnection, module_path: PathBuf, label: String, manufacturer_id: Option<String>, model: Option<String>, serial_number: String, concurrent_requests: Option<NonZeroU32>, ) -> Result<Self, Error>

pub async fn get(conn: &mut SqliteConnection, id: i64) -> Result<Self, Error>

pub async fn list(conn: &mut SqliteConnection) -> Result<Vec<Self>, Error>

pub fn intialize(&self) -> Result<Pkcs11>

Initialize the PKCS#11 module.

The caller must finalize it.

pub fn slot(&self, pkcs11: &Pkcs11) -> Result<Slot>

Find the Slot that contains the token.