pub struct Pkcs11Token {
pub id: i64,
pub module_path: PathBuf,
pub label: String,
pub manufacturer_id: Option<String>,
pub model: Option<String>,
pub serial_number: String,
pub concurrent_requests: i64,
}Fields
id: i64The table’s primary key.
module_path: PathBufAbsolute path to the PKCS#11 module to use when accessing the token.
label: StringThe token’s label, useful for identification purposes
manufacturer_id: Option<String>The token’s manufacturer ID, useful for identification purposes
model: Option<String>The token’s model, useful for identification purposes
serial_number: StringThe token’s serial number; used to find the token among all available PKCS#11 slots managed by the given module.
concurrent_requests: i64The number of concurrent signing requests; this translates to the number of open sessions and signing operations. Some tokens have limits. The default, 0, means no limit.
Implementations
Sourceimpl Pkcs11Token
impl Pkcs11Token
pub async fn create( conn: &mut SqliteConnection, module_path: PathBuf, label: String, manufacturer_id: Option<String>, model: Option<String>, serial_number: String, concurrent_requests: Option<NonZeroU32>, ) -> Result<Self, Error>
pub async fn get(conn: &mut SqliteConnection, id: i64) -> Result<Self, Error>
pub async fn list(conn: &mut SqliteConnection) -> Result<Vec<Self>, Error>